@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 use Courriel::HeaderAttribute;
 use Courriel::Helpers qw( unique_boundary );
@@ -43,17 +43,19 @@ sub BUILD {
     my $self = shift;
     my $p    = shift;
 
-    my $boundary = delete $p->{boundary} // unique_boundary();
-    my $existing = $self->content_type()->attribute('boundary');
+    my $boundary = delete $p->{boundary} // unique_boundary;
+    my $existing = $self->content_type->attribute('boundary');
 
-    $self->content_type()->_set_attribute(
+    ## no critic (Subroutines::ProtectPrivateSubs)
+    $self->content_type->_set_attribute(
         boundary => Courriel::HeaderAttribute->new(
-            name => ( $existing ? $existing->name() : 'boundary' ),
+            name => ( $existing ? $existing->name : 'boundary' ),
             value => $boundary,
         )
     );
+    ## use critic
 
-    $_->_set_container($self) for $self->parts();
+    $_->_set_container($self) for $self->parts;
 
     return;
 }
@@ -67,14 +69,14 @@ sub _stream_content {
     my $self   = shift;
     my $output = shift;
 
-    $output->( $self->preamble(), $Courriel::Helpers::CRLF )
-        if $self->has_preamble();
+    $output->( $self->preamble, $Courriel::Helpers::CRLF )
+        if $self->has_preamble;
 
-    for my $part ( $self->parts() ) {
+    for my $part ( $self->parts ) {
         $output->(
             $Courriel::Helpers::CRLF,
             '--',
-            $self->boundary(),
+            $self->boundary,
             $Courriel::Helpers::CRLF,
         );
 
@@ -84,13 +86,13 @@ sub _stream_content {
     $output->(
         $Courriel::Helpers::CRLF,
         '--',
-        $self->boundary(),
+        $self->boundary,
         '--',
         $Courriel::Helpers::CRLF
     );
 
-    $output->( $self->epilogue(), $Courriel::Helpers::CRLF )
-        if $self->has_epilogue();
+    $output->( $self->epilogue, $Courriel::Helpers::CRLF )
+        if $self->has_epilogue;
 
     return;
 }
@@ -99,10 +101,10 @@ sub _stream_content {
 sub boundary {
     my $self = shift;
 
-    return $self->content_type()->attribute_value('boundary');
+    return $self->content_type->attribute_value('boundary');
 }
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -118,12 +120,12 @@ Courriel::Part::Multipart - A part which contains other parts
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 SYNOPSIS
 
-  my $headers = $part->headers();
-  my $ct = $part->content_type();
+  my $headers = $part->headers;
+  my $ct = $part->content_type;
 
   for my $subpart ( $part->parts ) { ... }
 
@@ -226,8 +228,6 @@ output can be a subroutine reference, a filehandle, or an object with a
 C<print()> method. The output may be sent as a single string, as a list of
 strings, or via multiple calls to the output.
 
-See the C<as_string()> method for documentation on the C<charset> parameter.
-
 =head2 $part->as_string()
 
 Returns the part as a string, along with its headers. Lines will be terminated
