@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 use List::AllUtils qw( all );
 use Scalar::Util qw( blessed );
@@ -37,7 +37,7 @@ subtype EmailAddressStr,
 
 coerce EmailAddressStr,
     from class_type('Email::Address'),
-    via { $_->format() };
+    via { $_->format };
 
 my $_check_header_array = sub {
     return 0 unless @{$_} % 2 == 0;
